import Client from "../Client.js";

let changeListeners = [];
let initialized = false;
let blogposts = [];

let notifyChange = () => {
    changeListeners.forEach((listener) => {
        listener();
    });
}

let fetchBlogposts = () => {
    
    if (initialized) {
        return;
    }

    Client.getItems({
        "system.type": "blog_post",
        "elements" : "title,date,header_image,perex,url_slug",
        "order": "elements.date[desc]",
        "limit": "5"
    }).then((response) => {
        blogposts = response.items;
        notifyChange();
    });

    
    initialized = true;
}

class BlogPostStore {
    // Actions

    provideBlogposts() {
        fetchBlogposts();
    }

    // Methods
    getBlogposts(count) {
        return blogposts.slice(0, count);
    }

    // Listeners

    addChangeListener(listener) {
        changeListeners.push(listener);
    }

    removeChangeListener(listener) {
        changeListeners = changeListeners.filter((element) => {
            return element !== listener;
        });
    }

}

export default new BlogPostStore();